@@ -7,6 +7,8 @@
 #include <cmath>
 
 
+#include "range.h"
+typedef range_base<double> range;
 
 double catt(const ct2x3 &ct, double theta);
 
@@ -41,10 +43,28 @@ inline double catt_max(const ct2x3 &ct, bool useMax3 = true, Alternative alter=T
 
 double catt_p(const ct2x3 &ct, double theta, Alternative alter=TWO_SIDE);
 
-class maxacter
+class MaXact
 {
+ private:
+  ct2x3 _ct;
+  bool _useMax3;
+  Alternative _alter;
+  double _p, _d; // d is the test statistics
+  double _dAdjust;
+  range _rns[3];
+  range _rbys[3]; //constrain by sum_col, sum_row
+  double _logPathAll, _logConst;
+  double proportionAcceptPoint();
+  void calculateSmallP();
+  void calculateP();
 public:
-  double p(const ct2x3 &ct, bool useMax3 = true, Alternative alter=TWO_SIDE);
+  MaXact(const ct2x3 &ct, bool useMax3 = true, Alternative alter=TWO_SIDE);
+  inline double p(){
+    return _p;
+  }
+  inline double stat(){
+    return _d;
+  }
 };
 
 
